# -*- coding: utf-8 -*-

import pytest

from colorama import Fore, Back

from click.testing import CliRunner
from wallabag.api.api import Response, RequestException
from wallabag.api.get_entry import GetEntry
from wallabag.commands.show import ShowCommand, ShowCommandParams, Alignment
from wallabag.config import Configs
from wallabag import wallabag


def config__is_valid(self):
    return True


class TestShowCommand():

    runner = CliRunner()

    def setup_method(self, method):
        self.config = Configs("/tmp/config")
        self.config.config.read_string("""
                [api]
                serverurl = url
                username = user
                password = pass
                [oauth2]
                client = 100
                secret = 100
                """)

    def test_entry_not_exist(self, monkeypatch):
        def request(self):
            response = Response(404, None)
            raise RequestException(
                    response.error_text, response.error_description)
        monkeypatch.setattr(GetEntry, 'request', request)

        result, output = ShowCommand(
                self.config, ShowCommandParams(1000)).execute()
        assert not result
        assert output == "Error: 404: API was not found."

    def test_entry_content(self, monkeypatch):
        def request(self):
            return Response(
                    200, '{"id": 1, "title": "title", "content": "content",\
                            "url": "url", "is_archived": 0, "is_starred": 1}')

        monkeypatch.setattr(GetEntry, 'request', request)

        params = ShowCommandParams(1)
        params.width = '100%'
        result, output = ShowCommand(self.config, params).execute()
        assert result
        assert output == f'title\n{"="*ShowCommand.FAILWIDTH}\ncontent'

    def test_entry_html_content(self, monkeypatch):
        def request(self):
            return Response(
                    200, '{"id": 1, "title": "title", "content": "<h1>head</h1>content",\
                            "url": "url", "is_archived": 0, "is_starred": 1}')

        monkeypatch.setattr(GetEntry, 'request', request)

        params = ShowCommandParams(1, html=True)
        params.width = '100%'
        result, output = ShowCommand(self.config, params).execute()
        assert result
        assert output == (
                f'title\n{"="*ShowCommand.FAILWIDTH}\n'
                '<h1>head</h1>content')

    def test_entry_html_strip_content(self, monkeypatch):
        def request(self):
            return Response(
                    200, '{"id": 1, "title": "title", "content": "<h1>head</h1>content",\
                            "url": "url", "is_archived": 0, "is_starred": 1}')

        monkeypatch.setattr(GetEntry, 'request', request)

        params = ShowCommandParams(1, html=False, colors=False)
        params.width = '100%'
        result, output = ShowCommand(self.config, params).execute()
        assert result
        assert output == (
                f'title\n{"="*ShowCommand.FAILWIDTH}\n\n\n'
                'head\ncontent')

    def test_entry_html_strip_content_with_colors(self, monkeypatch):
        def request(self):
            return Response(
                    200, '{"id": 1, "title": "title", "content": "<h1>head</h1>content",\
                            "url": "url", "is_archived": 0, "is_starred": 1}')

        monkeypatch.setattr(GetEntry, 'request', request)

        params = ShowCommandParams(1, html=False, colors=True)
        params.width = '100%'
        result, output = ShowCommand(self.config, params).execute()
        assert result
        assert output == (
                f'title\n{"="*ShowCommand.FAILWIDTH}\n\n\n'
                f'{Fore.BLUE}head{Fore.RESET}\ncontent')

    def test_entry_html_image_content(self, monkeypatch):
        def request(self):
            return Response(
                    200, '{"id": 1, "title": "title", "content":\
                            "<h1>head</h1>content<img alt=\\"Message desc\\"\
                            src=\\"https://imag.es/1.jpg\\" />",\
                            "url": "url", "is_archived": 0, "is_starred": 1}')

        monkeypatch.setattr(GetEntry, 'request', request)

        params = ShowCommandParams(1, html=False, colors=False)
        params.width = '100%'
        result, output = ShowCommand(self.config, params).execute()
        assert result
        assert output == (
                f'title\n{"="*ShowCommand.FAILWIDTH}\n\n\n'
                'head\ncontent [IMAGE "Message desc"]')

    def test_entry_html_image_content_with_links(self, monkeypatch):
        def request(self):
            return Response(
                    200, '{"id": 1, "title": "title", "content":\
                            "<h1>head</h1>content<img alt=\\"Message desc\\"\
                            src=\\"https://imag.es/1.jpg\\" />",\
                            "url": "url", "is_archived": 0, "is_starred": 1}')

        monkeypatch.setattr(GetEntry, 'request', request)

        params = ShowCommandParams(
                1, html=False, colors=False, image_links=True)
        params.width = '100%'
        result, output = ShowCommand(self.config, params).execute()
        assert result
        assert output == (
                f'title\n{"="*ShowCommand.FAILWIDTH}\n\n\nhead\ncontent '
                '[IMAGE "Message desc" (https://imag.es/1.jpg)]')

    def test_entry_html_image_content_with_annotations(self, monkeypatch):
        def request(self):
            return Response(
                    200, (
                        '{"id": 1, "title": "title", "content":'
                        '"<h1>header text</h1>content<img alt=\\"Message\\"'
                        'src=\\"https://imag.es/1.jpg\\" />",'
                        '"url": "url", "is_archived": 0, "is_starred": 1,'
                        '"annotations":[{'
                        '"user": "User", "annotator_schema_version":'
                        ' "v1.0", "id": 1, "text": "content", '
                        '"created_at": "2020-10-28T10:50:51+0000", '
                        '"updated_at": "2020-10-28T10:50:51+0000", '
                        '"quote": "quote", "ranges": '
                        '[{"start": "/h1", "startOffset": "2", '
                        '"end": "/h1", "endOffset": "4"}]}]}'))

        monkeypatch.setattr(GetEntry, 'request', request)

        params = ShowCommandParams(
                1, html=False, colors=True, image_links=True)
        params.width = '100%'
        result, output = ShowCommand(self.config, params).execute()
        assert result
        assert output == (
            f'title\n{"="*ShowCommand.FAILWIDTH}\n\n\n'
            f'{Fore.BLUE}he{Back.CYAN}ad{Back.RESET} [1]er text'
            f'{Fore.RESET}\ncontent '
            '[IMAGE "Message" (https://imag.es/1.jpg)]')

    def test_entry_html_content_with_annotations_multiline(
            self, monkeypatch):
        def request(self):
            return Response(
                200, ('{"id": 1, "title": "title", "content":'
                      '"<h1>header text</h1>content<p>end anno</p>",'
                      '"url": "url", "is_archived": 0, "is_starred": 1,'
                      '"annotations":[{'
                      '"user": "User", "annotator_schema_version":'
                      ' "v1.0", "id": 1, "text": "content", '
                      '"created_at": "2020-10-28T10:50:51+0000", '
                      '"updated_at": "2020-10-28T10:50:51+0000", '
                      '"quote": "quote", "ranges": '
                      '[{"start": "/h1", "startOffset": "2", '
                      '"end": "/p", "endOffset": "4"}]}]}'))

        monkeypatch.setattr(GetEntry, 'request', request)

        params = ShowCommandParams(
                1, html=False, colors=True, image_links=True)
        params.width = '100%'
        result, output = ShowCommand(self.config, params).execute()
        assert result
        assert output == (
                f'title\n{"="*ShowCommand.FAILWIDTH}\n\n\n'
                f'{Fore.BLUE}he{Back.CYAN}ader text'
                f'{Fore.RESET}\ncontent\n\nend {Back.RESET} [1]anno')

    @pytest.mark.parametrize('values', [
        ('50%', " "*25, "="*int(ShowCommand.FAILWIDTH/2)),
        ('200', "", "="*ShowCommand.FAILWIDTH),
        ('70', " "*15, "="*70)])
    def test_custom_width(self, monkeypatch, values):
        def request(self):
            return Response(
                    200, '{"id": 1, "title": "title", "content": "content",\
                            "url": "url", "is_archived": 0, "is_starred": 1}')

        monkeypatch.setattr(GetEntry, 'request', request)

        params = ShowCommandParams(1)
        params.width = values[0]
        result, output = ShowCommand(self.config, params).execute()
        assert result
        assert output == (
                f'{values[1]}title\n{values[1]}'
                f'{values[2]}\n{values[1]}content')

    @pytest.mark.parametrize('values', [
        ('80%', Alignment.CENTER,
            (ShowCommand.FAILWIDTH - ShowCommand.FAILWIDTH * 80 / 100) / 2,
            (ShowCommand.FAILWIDTH * 80 / 100)),
        ('80%', Alignment.RIGHT,
            (ShowCommand.FAILWIDTH - ShowCommand.FAILWIDTH * 80 / 100),
            (ShowCommand.FAILWIDTH * 80 / 100)),
        ('80%', Alignment.LEFT, 0, (ShowCommand.FAILWIDTH * 80 / 100))])
    def test_alignment(self, monkeypatch, values):
        def request(self):
            return Response(
                    200, '{"id": 1, "title": "title", "content": "content",\
                            "url": "url", "is_archived": 0, "is_starred": 1}')

        monkeypatch.setattr(GetEntry, 'request', request)

        params = ShowCommandParams(1)
        params.width = values[0]
        params.align = values[1]
        result, output = ShowCommand(self.config, params).execute()
        assert result
        assert output == (
                f'{" "*int(values[2])}title\n'
                f'{" "*int(values[2])}{"="*int(values[3])}\n'
                f'{" "*int(values[2])}content')

    def test_command_show(self, monkeypatch):
        command_runned = False

        def run_command(command, quiet=False):
            nonlocal command_runned
            command_runned = True
            assert command.__class__.__name__ == 'ShowCommand'
            assert command.params.entry_id == '1'
            assert command.params.align == Alignment.LEFT
            assert command.params.raw

        monkeypatch.setattr(wallabag, 'run_command', run_command)
        monkeypatch.setattr(Configs, 'is_valid', config__is_valid)

        result = self.runner.invoke(
                wallabag.cli, ['show', '-r', '-a', 'left', '1'],
                catch_exceptions=False)
        assert result.exit_code == 0
        assert command_runned



# -*- coding: utf-8 -*-

from wallabag.api.api import Api, ApiMethod, ValueException


class ExportEntry(Api):

    def __init__(self, config, entry_id, format):
        Api.__init__(self, config)
        self.entry_id = entry_id
        self.format = format

    def _get_api_url(self):
        entry_id = self._validate_identificator(self.entry_id)
        url = self._build_url(ApiMethod.GET_ENTRY).format(entry_id)
        if not self.format:
            raise ValueException('Format is not specified')
        return f'{url}/export.{self.format}'

    def _make_request(self, request):
        return self._request_get(request)



# -*- coding: utf-8 -*-

import os
import textwrap
from enum import Enum, auto
from bs4 import BeautifulSoup
from colorama import Fore, Back
from lxml import etree

from wallabag.api.get_entry import GetEntry
from wallabag.commands.command import Command
from wallabag.commands.params import Params
from wallabag.entry import Entry


class Alignment(Enum):
    CENTER = auto()
    LEFT = auto()
    RIGHT = auto()

    def list():
        return [c.name for c in Alignment]

    def get(name):
        for align in Alignment:
            if align.name == name.upper():
                return align
        return Alignment.CENTER


class ShowCommandParams(Params):
    width = '80%'
    align = Alignment.CENTER

    def __init__(self, entry_id, colors=True, html=False,
                 raw=False, image_links=False):
        self.entry_id = entry_id
        self.colors = colors
        self.html = html
        self.raw = raw
        self.image_links = image_links


class ShowCommand(Command):

    FAILWIDTH = 100

    def __init__(self, config, params):
        Command.__init__(self)
        self.config = config
        self.params = params

    def _run(self):
        api = GetEntry(self.config, self.params.entry_id)
        entry = Entry(api.request().response)

        self.__calculate_alignment()

        article = entry.content
        if not self.params.html:
            article = self.__html2text(article, entry.annotations)

        output = f"{entry.title}\n{self.__header_delimiter()}\n{article}"
        if not self.params.raw:
            output = self.__format_output(output)
        return True, output

    def __calculate_alignment(self):
        try:
            self.maxcol = os.get_terminal_size().columns
        except OSError:
            self.maxcol = ShowCommand.FAILWIDTH

        self.width = self.maxcol
        if self.params.width:
            if '%' in self.params.width:
                percent = int(self.params.width[:-1])
                self.width = int(self.width * percent / 100)
            else:
                self.width = int(self.params.width)
                if self.width > self.maxcol:
                    self.width = self.maxcol

    def __format_output(self, output):
        result = []
        for line in output.splitlines():
            result.extend(textwrap.wrap(line, self.width) if line else [''])
        result = textwrap.indent(
                "\n".join(result), ' ' * self.__indent(self.params.align))
        return result

    def __indent(self, align):
        if align == Alignment.CENTER:
            return int((self.maxcol - self.width) / 2)
        elif align == Alignment.RIGHT:
            return self.maxcol - self.width
        return 0

    def __html2text(self, html, annotations):
        soup = self.__mark_annotations(html, annotations)
        self.__color_headers(soup)
        self.__color_bold(soup)
        self.__make_hr(soup)
        self.__replace_images(soup)
        self.__break_paragraphs(soup)
        return self.__make_annotations(
                soup, annotations).replace('\n\n\n', '\n\n')

    def __break_paragraphs(self, soup):
        for p in soup.findAll('p'):
            p.insert_before(self.__get_new_line_tag(soup, times=2))

    def __mark_annotations(self, html, annotations):
        soup = BeautifulSoup(html, "html.parser")
        if annotations:
            dom = etree.HTML(str(soup))
            for anno in annotations:
                anno_id = f"__anno-{anno['id']}__"
                startOffset = int(anno['ranges'][0]['startOffset'])
                endOffset = int(anno['ranges'][0]['endOffset'])
                el_start = dom.xpath('/' + anno['ranges'][0]['start'])[0]
                el_end = dom.xpath('/' + anno['ranges'][0]['end'])[0]
                el_start.text = "".join([
                        el_start.text[:startOffset],
                        f'{anno_id}_start',
                        el_start.text[startOffset:]])
                if el_start == el_end:
                    endOffset += len(f'{anno_id}_start')
                el_end.text = "".join([
                        el_end.text[:endOffset],
                        f'{anno_id}_end',
                        el_end.text[endOffset:]])
            return BeautifulSoup(
                    etree.tostring(dom, method='html'), "html.parser")
        return soup

    def __make_annotations(self, soup, annotations):
        text = soup.text
        for anno in annotations:
            anno_id = f"__anno-{anno['id']}__"
            text = text.replace(
                    f'{anno_id}_start', Back.CYAN).replace(
                            f'{anno_id}_end', f'{Back.RESET} [{anno["id"]}]')
        return text

    def __header_delimiter(self):
        try:
            return "".ljust(self.width, '=')
        except OSError:
            return "\n"

    def __color_headers(self, soup):
        if self.params.colors:
            h1colors = Fore.BLUE
            h1colore = Fore.RESET
        else:
            h1colors = h1colore = ""
        for header in ['h1', 'h2', 'h3']:
            for h in soup.findAll(header):
                h.string = f"{h1colors}{h.string}{h1colore}"
                h.insert_before(self.__get_new_line_tag(soup, 2))
                h.insert_after(self.__get_new_line_tag(soup))
                h.unwrap()

    def __get_new_line_tag(self, soup, times=1):
        span = soup.new_tag('span')
        span.string = "\n" * times
        return span

    def __color_bold(self, soup):
        if self.params.colors:
            bcolors = Fore.RED
            bcolore = Fore.RESET
            for bold in ['b', 'strong']:
                for b in soup.findAll('b'):
                    b.string = f"{bcolors}{b.string}{bcolore}"

    def __make_hr(self, soup):
        try:
            print(self.width)
            hrstring = "".ljust(self.width, '-')
        except OSError:
            hrstring = "-----"
        for hr in soup.findAll('hr'):
            replace = soup.new_tag('p')
            replace.string = hrstring
            hr.insert_after(replace)
            hr.unwrap()

    def __replace_images(self, soup):
        for img in soup.findAll('img'):
            replace = soup.new_tag('span')
            try:
                alt = f" \"{img['alt']}\""
            except KeyError:
                alt = ""
            links = ""
            if self.params.image_links:
                links = f" ({img['src']})"
            replace.string = f" [IMAGE{alt}{links}]\n"
            img.insert_after(replace)
            img.unwrap()



# -*- coding: utf-8 -*-

import pytest

from wallabag.api.api import ApiMethod, ValueException
from wallabag.api.export_entry import ExportEntry
from wallabag.config import Configs


class TestExportEntry():

    def setup_method(self, method):
        self.config = Configs("/tmp/config")
        self.config.config.read_string("""
                [api]
                serverurl = url
                username = user
                password = pass
                [oauth2]
                client = 100
                secret = 100
                """)

    @pytest.mark.parametrize('values', [('10', 'mobi'), (10, 'epub')])
    def test_api_url(self, values):
        api = ExportEntry(self.config, values[0], values[1])

        url = "url" + ApiMethod.GET_ENTRY.value.format(values[0])
        assert f'{url}/export.{values[1]}' == api._get_api_url()

    def test_api_url_none_format(self):
        api = ExportEntry(self.config, 10, '')

        with pytest.raises(ValueException):
            api._get_api_url()



# -*- coding: utf-8 -*-

import os
import pytest
import re
from pathlib import PurePath, Path

from click.testing import CliRunner
from wallabag.config import Configs
from wallabag.commands.export import (
        ExportCommand, ExportCommandParams, FormatType)
from wallabag.api.api import Response
from wallabag.api.export_entry import ExportEntry
from wallabag import wallabag


def config__is_valid(self):
    return True


class TestExport():

    runner = CliRunner()

    def setup_method(self, method):
        self.config = Configs("/tmp/config")
        self.config.config.read_string("""
                [api]
                serverurl = url
                username = user
                password = pass
                [oauth2]
                client = 100
                secret = 100
                """)

    def test_export(self, monkeypatch, tmp_path):

        def export_entry(self):
            return Response(200, None, b'123', 'application/epub')

        monkeypatch.setattr(ExportEntry, 'request', export_entry)

        params = ExportCommandParams(
                    10, FormatType.get(
                        'epub'), PurePath(f'{tmp_path}/file.epub'))
        params.filename_with_id = False
        result, msg = ExportCommand(
                self.config, params).execute()
        assert result
        assert msg == f'Exported to: {tmp_path}/file.epub'

    def test_empty_output(self, monkeypatch, tmpdir):

        def export_entry(self):
            return Response(
                    200, None, b'123', 'application/epub')

        monkeypatch.setattr(ExportEntry, 'request', export_entry)

        result, msg = ExportCommand(
                self.config, ExportCommandParams(
                    10, FormatType.get('epub'), PurePath(tmpdir))).execute()
        assert result
        assert re.search(f'Exported to: {PurePath(tmpdir)}/.+.epub', msg)

    def test_non_existed_directory(self, monkeypatch, tmpdir):

        def export_entry(self):
            return Response(
                    200, None, b'123', 'application/epub')

        monkeypatch.setattr(ExportEntry, 'request', export_entry)

        tmpdir = tmpdir + '/new_dir/'
        result, msg = ExportCommand(
                self.config, ExportCommandParams(
                    10, FormatType.get('epub'), PurePath(tmpdir))).execute()
        assert result
        assert re.search(f'Exported to: {PurePath(tmpdir)}/.+.epub', msg)

    def test_empty_output_cdisposition(self, monkeypatch):

        def export_entry(self):
            return Response(
                    200, None, b'123', 'application/epub',
                    'attachment; filename="file.epub"')

        monkeypatch.setattr(ExportEntry, 'request', export_entry)

        result, msg = ExportCommand(
                self.config, ExportCommandParams(
                    10, FormatType.get('epub'))).execute()
        assert result
        assert msg == f'Exported to: {Path.cwd()}/10. file.epub'

        os.remove(f'{Path.cwd()}/10. file.epub')

    def test_wrong_format_type(self, monkeypatch, tmpdir):

        def export_entry(self):
            return Response(200, None, b'123', 'application/epub')

        monkeypatch.setattr(ExportEntry, 'request', export_entry)

        command = ExportCommand(
                self.config, ExportCommandParams(
                    10, FormatType.get('epub2'), PurePath(tmpdir)))
        result, msg = command.execute()

        assert result
        assert command.params.format == FormatType.get('json')

    def test_format_not_specified(self):
        result, msg = ExportCommand(
                self.config, ExportCommandParams(10, None)).execute()

        assert not result
        assert msg == 'Format type not specified'

    @pytest.mark.parametrize('values', [
        (None, 'Entry ID not specified'),
        (-10, 'Entry ID not specified'),
        ('-10', 'Entry ID not specified'),
        ('foo', 'Wrong Entry ID value')])
    def test_wrong_entry_id(self, values):
        result, msg = ExportCommand(
                self.config, ExportCommandParams(
                    values[0], FormatType.get('json'))).execute()

        assert not result
        assert msg == values[1]

    def test_command_export(self, monkeypatch):
        command_runned = False

        def run_command(command, quiet=False):
            nonlocal command_runned
            command_runned = True
            assert command.__class__.__name__ == 'ExportCommand'
            assert command.params.entry_id == '1'

        monkeypatch.setattr(wallabag, 'run_command', run_command)
        monkeypatch.setattr(Configs, 'is_valid', config__is_valid)

        result = self.runner.invoke(
                wallabag.cli, ['export', '1'], catch_exceptions=False)
        assert command_runned
        assert result.exit_code == 0

    def test_command_export_format(self, monkeypatch):
        command_runned = False

        def run_command(command, quiet=False):
            nonlocal command_runned
            command_runned = True
            assert command.__class__.__name__ == 'ExportCommand'
            assert command.params.entry_id == '1'
            assert command.params.format.name == 'PDF'

        monkeypatch.setattr(wallabag, 'run_command', run_command)
        monkeypatch.setattr(Configs, 'is_valid', config__is_valid)

        result = self.runner.invoke(
                wallabag.cli, ['export', '1', '-f', 'pdf'],
                catch_exceptions=False)
        assert command_runned
        assert result.exit_code == 0

    def test_command_export_output(self, monkeypatch):
        command_runned = False

        def run_command(command, quiet=False):
            nonlocal command_runned
            command_runned = True
            assert command.__class__.__name__ == 'ExportCommand'
            assert command.params.entry_id == '1'
            assert command.params.output_file == PurePath('/tmp')

        monkeypatch.setattr(wallabag, 'run_command', run_command)
        monkeypatch.setattr(Configs, 'is_valid', config__is_valid)

        result = self.runner.invoke(
                wallabag.cli, ['export', '1', '-f', 'pdf', '-o', '/tmp'],
                catch_exceptions=False)
        assert command_runned
        assert result.exit_code == 0



# -*- coding: utf-8 -*-

from datetime import datetime
from enum import Enum, auto
from pathlib import PurePath, Path

from wallabag.commands.params import Params
from wallabag.commands.command import Command
from wallabag.api.export_entry import ExportEntry
from wallabag.api.get_entry import GetEntry
from wallabag.entry import Entry


class FormatType(Enum):
    XML = auto()
    JSON = auto()
    TXT = auto()
    CSV = auto()
    PDF = auto()
    EPUB = auto()
    MOBI = auto()
    HTML = auto()

    def list():
        return [c.name for c in FormatType]

    def get(name):
        for format in FormatType:
            if format.name == name.upper():
                return format
        return FormatType.JSON


class ExportCommandParams(Params):
    entry_id = None
    format = None
    output_file = None
    filename_with_id = True

    def __init__(
            self, entry_id, format: FormatType, output_file: PurePath = None):
        self.entry_id = entry_id
        self.format = format
        self.output_file = output_file

    def validate(self):
        try:
            if not self.entry_id or int(self.entry_id) < 0:
                return False, 'Entry ID not specified'
        except ValueError:
            return False, 'Wrong Entry ID value'

        if not self.format:
            return False, 'Format type not specified'

        if not self.output_file:
            self.output_file = Path.cwd()

        return True, None


class ExportCommand(Command):

    def __init__(self, config, params):
        Command.__init__(self)
        self.config = config
        self.params = params

    def _run(self):
        format = self.params.format.name.lower()
        output_file = self.params.output_file
        result = ExportEntry(
                self.config,
                self.params.entry_id,
                format).request()
        if output_file.name.endswith(f'.{format}'):
            result.filename = output_file.name
            output_file = output_file.parent
        if not Path(output_file).exists():
            Path(output_file).mkdir(parents=True)
        if result.filename:
            if result.filename.startswith('.'):
                entry = Entry(
                        GetEntry(
                            self.config,
                            self.params.entry_id).request().response)
                result.filename = f'{entry.title}{result.filename}'
            new_name = result.filename
        else:
            new_name = str(f'{datetime.now().timestamp()}.{format}')
        output_file = PurePath(
                f'{Path(output_file).resolve()}/'
                f'{self.__get_filename(new_name)}')

        with open(output_file, 'wb') as file:
            file.write(result.content)
        return True, f'Exported to: {output_file}'

    def __get_filename(self, name):
        if self.params.filename_with_id:
            return f'{self.params.entry_id}. {name}'
        return name
